from __future__ import print_function, division, absolute_import
import argparse
from argparse import RawDescriptionHelpFormatter
import sys

from conda.cli import common


description = """
Handles interacting with Conda environments.
"""

example = """
examples:
    conda env list
    conda env list --json
"""


def configure_parser():
    p = argparse.ArgumentParser()
    sub_parsers = p.add_subparsers()

    l = sub_parsers.add_parser(
        'list',
        formatter_class=RawDescriptionHelpFormatter,
        description=description,
        help=description,
        epilog=example,
    )

    common.add_parser_json(l)

    return p


def main():
    args = configure_parser().parse_args()
    info_dict = {'envs': []}
    common.handle_envs_list(args, info_dict['envs'])

    if args.json:
        common.stdout_json(info_dict)


if __name__ == '__main__':
    sys.exit(main())



#!/usr/bin/env python
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

import versioneer


if sys.version_info[:2] < (2, 7):
    sys.exit("conda is only meant for Python 2.7, with experimental support "
             "for python 3.  current version: %d.%d" % sys.version_info[:2])

versioneer.versionfile_source = 'conda_env/_version.py'
versioneer.versionfile_build = 'conda_env/_version.py'
versioneer.tag_prefix = ''
versioneer.parentdir_prefix = 'conda-env-'

setup(
    name="conda-env",
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    author="Continuum Analytics, Inc.",
    author_email="travis.swicegood@continuum.io",
    url="https://github.com/tswicegood/conda-build",
    license="BSD",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
    ],
    description="tools for interacting with conda environments",
    long_description=open('README.rst').read(),
    packages=['conda_env'],
    scripts=[
        'bin/conda-env',
    ],
    install_requires=['conda'],
    package_data={},
)




# This file was generated by 'versioneer.py' (0.7+) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

version_version = 'v0.1.0'
version_full = '2ec467a6f5d61ae4ad94638eccece47ab4db3fc4'
def get_versions(default={}, verbose=False):
    return {'version': version_version, 'full': version_full}

